Crate linera_wit_bindgen_host_wasmtime_rust_macro
Source - export
- Generate code to support implementing the given interfaces and exporting
them to wasm modules.
- import
- Generate code to support consuming the given interfaces, importaing them
from wasm modules.